@@ -20,19 +20,8 @@ def puts(clr):
     fmt = '\x1b[48;5;%sm  \x1b[0m'
     return fmt % c.x256
 
-def main(args):
-
-    if args.imfile.startswith('http'):
-        req = requests.get(args.imfile)
-        im = Image.open(StringIO(req.content))
-    else:
-        im = Image.open(args.imfile)
-
-    maxw = int(args.columns / 2)
-    maxh = int(maxw * (float(im.size[1])/im.size[0]))
-    maxsize = maxw if maxw > maxh else maxh
-    im.thumbnail((maxsize, maxsize), Image.ANTIALIAS)
 
+def flush(im):
     w, h = im.size
     pxs = im.load()
     alpha = len(pxs[0, 0]) == 4
@@ -45,6 +34,22 @@ def main(args):
                 sys.stdout.write(puts(px[:3]))
         sys.stdout.write('\n')
 
+
+def main(args):
+
+    if args.imfile.startswith('http'):
+        req = requests.get(args.imfile)
+        im = Image.open(StringIO(req.content))
+    else:
+        im = Image.open(args.imfile)
+
+    maxw = int(args.columns / 2)
+    maxh = int(maxw * (float(im.size[1]) / im.size[0]))
+    maxsize = maxw if maxw > maxh else maxh
+    im.thumbnail((maxsize, maxsize), Image.ANTIALIAS)
+    flush(im)
+
+
 def cli():
     import argparse
 
@@ -53,9 +58,9 @@ def cli():
     desc += '\nhttp://github.com/philadams/lores'
     parser = argparse.ArgumentParser(description=desc)
     parser.add_argument('imfile',
-            help='image file to render')
+                        help='image file to render')
     parser.add_argument('-c', '--columns', dest='columns', type=int,
-            default=80, help='width of img in terminal columns')
+                        default=80, help='width of img in terminal columns')
     args = parser.parse_args()
 
     main(args)
